@@ -1,6 +1,7 @@
 use std::*;
 use structopt::StructOpt;
 mod replacer;
+use replacer::Changed;
 use tempfile::NamedTempFile;
 
 #[derive(Debug, StructOpt)]
@@ -36,18 +37,32 @@ fn process_file(args: &Opt, file: &path::PathBuf) {
         return;
     }
     let tmp = NamedTempFile::new_in("").unwrap();
+    let replace_file = |changed| match changed {
+        Changed::Yes => {
+            fs::rename(&tmp.path(), &file).unwrap();
+        }
+        _ => (),
+    };
 
     if args.inplace {
         match args.delete {
-            true => replacer::delete_matches(args, file, &tmp),
-            false => replacer::replace_matches(args, file, &tmp),
+            true => {
+                let changed = replacer::delete_matches(args, file, &tmp);
+                replace_file(changed);
+            }
+            false => {
+                let changed = replacer::replace_matches(args, file, &tmp);
+                replace_file(changed);
+            }
         }
     } else {
         match args.delete {
-            true => replacer::delete_matches(args, file, io::stdout()),
-            false => replacer::replace_matches(args, file, io::stdout()),
+            true => {
+                let _ = replacer::delete_matches(args, file, io::stdout());
+            }
+            false => {
+                let _ = replacer::replace_matches(args, file, io::stdout());
+            }
         }
     }
-
-    fs::rename(&tmp.path(), &file).unwrap();
 }
